@@ -1,7 +1,9 @@
 #!/usr/bin/env python
+from __future__ import print_function
 from rplidar import *
 import argparse
 import stretch_body.hello_utils as hu
+from stretch_body.device import Device
 hu.print_stretch_re_use()
 
 parser=argparse.ArgumentParser(description='Tool to control the RP-Lidar')
@@ -14,7 +16,9 @@ parser.add_argument("--range", help="Print range reading",action="store_true")
 args=parser.parse_args()
 
 try:
-    lidar = RPLidar('/dev/hello-lrf')
+    lidar_dev = Device('lidar')
+    lidar_usb = lidar_dev.params['usb_name']
+    lidar = RPLidar(lidar_usb)
 except RPLidarException:
     print ('RPLidar not present')
     exit()
@@ -42,7 +46,7 @@ if args.range:
         if i > 0:
             break
         print('%d: Got %d measurments' % (i, len(scan)))
-        print 'Scan',scan
+        print('Scan',scan)
 
 
 if not args.motor_on: #Turn off motor by default
